.. include:: references.txt

.. _gala-user-guide:

**********
User Guide
**********

The user guide contains exhaustive descriptions of all of the functions and
classes available in ``gala``, with some inline narrative descriptions and
demonstrations of functionality. This portion of the documentation should be
treated like reference material, whereas the :ref:`gala-tutorials` show how
pieces of ``gala`` work together to meet more realistic research needs.

.. toctree::
    :maxdepth: 1

    conventions
    coordinates/index
    integrate/index
    potential/index
    dynamics/index
    units
    util
    interop

.. toctree::
    :hidden:

    glossary


Recent additions and changes
============================

.. toctree::
    :maxdepth: 2

    whatsnew/index
